@@ -34,12 +34,12 @@ You can find examples and howtos on L<http://rexify.org/>
 
  user "root";
  password "ch4ngem3";
-
+ 
  desc "Show Unix version";
  task "uname", sub {
     say run "uname -a";
  };
-
+ 
  bash# rex -H "server[01..10]" uname
 
 See L<Rex::Commands> for a list of all commands you can use.
@@ -70,7 +70,7 @@ use File::Basename;
 our ( @EXPORT, $VERSION, @CONNECTION_STACK, $GLOBAL_SUDO, $MODULE_PATHS,
   $WITH_EXIT_STATUS );
 
-$VERSION = "0.46.1";
+$VERSION = "0.46.3";
 my $cur_dir;
 
 BEGIN {
@@ -173,6 +173,10 @@ sub get_module_path {
 }
 
 sub push_connection {
+  if ( !ref $_[0]->{server} ) {
+    $_[0]->{server} = Rex::Group::Entry::Server->new( name => $_[0]->{server} );
+  }
+
   push @CONNECTION_STACK, $_[0];
   return $_[0];
 }
@@ -341,7 +345,7 @@ Use this function to create a connection if you use Rex as a library.
  use Rex;
  use Rex::Commands::Run;
  use Rex::Commands::Fs;
-
+ 
  Rex::connect(
    server    => "remotehost",
    user      => "root",
@@ -349,11 +353,11 @@ Use this function to create a connection if you use Rex as a library.
    private_key => "/path/to/private/key/file",
    public_key  => "/path/to/public/key/file",
  );
-
+ 
  if(is_file("/foo/bar")) {
    print "Do something...\n";
  }
-
+ 
  my $output = run("uptime");
 
 =cut
