@@ -111,8 +111,11 @@ sub __run__ {
     $Rex::Logger::silent = 0;
   }
 
+  Rex::Config->set_use_cache(1);
   if ( $opts{"c"} ) {
-    Rex::Config->set_use_cache(1);
+  #  Rex::Config->set_use_cache(1);
+  # since 0.46 just a pseudo option
+  # cache is enabled by default
   }
   elsif ( $opts{"C"} ) {
     Rex::Config->set_use_cache(0);
@@ -483,7 +486,11 @@ CHECK_OVERWRITE: {
       }
     }
     _print_color( "Environments\n", "yellow" );
-    print "  " . join( "\n  ", Rex::Commands->get_environments() ) . "\n";
+    my @envs = map { Rex::Commands->get_environment($_) }
+      Rex::Commands->get_environments();
+    for my $e (@envs) {
+      printf "  %-30s %s\n", $e->{name}, $e->{description};
+    }
 
     my %groups = Rex::Group->get_groups;
     _print_color( "Server Groups\n", "yellow" ) if ( keys %groups );
