@@ -21,7 +21,7 @@ With this module you can manipulate files.
    }
    $fh->close;
  };
-
+ 
  task "read-passwd2", "server01", sub {
    say cat "/etc/passwd";
  };
@@ -32,18 +32,18 @@ With this module you can manipulate files.
    $fh->write("root:*:0:0:root user:/root:/bin/sh\n");
    $fh->close;
  };
-
+ 
  delete_lines_matching "/var/log/auth.log", matching => "root";
  delete_lines_matching "/var/log/auth.log", matching => qr{Failed};
  delete_lines_matching "/var/log/auth.log",
                 matching => "root", qr{Failed}, "nobody";
-
+ 
  file "/path/on/the/remote/machine",
    source => "/path/on/local/machine";
-
+ 
  file "/path/on/the/remote/machine",
    content => "foo bar";
-
+ 
  file "/path/on/the/remote/machine",
    source => "/path/on/local/machine",
    owner  => "root",
@@ -82,7 +82,7 @@ use Rex::Interface::Exec;
 use Rex::Interface::File;
 use Rex::Interface::Fs;
 
-use File::Basename qw(dirname);
+use File::Basename qw(dirname basename);
 
 use vars qw(@EXPORT);
 use base qw(Rex::Exporter);
@@ -155,7 +155,11 @@ sub template {
       my $file_path = Rex::get_module_path($caller[0]);
 
       if(! -f $file_path) {
-        if(-f "$file_path/__module__.pm") {
+        my ($mod_name) = ($caller[0] =~ m/^.*::(.*?)$/);
+        if($mod_name && -f "$file_path/$mod_name.pm") {
+          $file_path = "$file_path/$mod_name.pm";
+        }
+        elsif(-f "$file_path/__module__.pm") {
           $file_path = "$file_path/__module__.pm";
         }
         elsif(-f "$file_path/Module.pm") {
@@ -214,33 +218,33 @@ This function is the successor of I<install file>. Please use this function to u
  task "prepare", "server1", "server2", sub {
    file "/file/on/remote/machine",
      source => "/file/on/local/machine";
-
+ 
    file "/etc/hosts",
      content => template("templates/etc/hosts.tpl"),
      owner  => "user",
      group  => "group",
      mode   => 700,
      on_change => sub { say "Something was changed." };
-
+ 
    file "/etc/motd",
      content => `fortune`;
-
+ 
    file "/etc/named.conf",
      content    => template("templates/etc/named.conf.tpl"),
      no_overwrite => TRUE;  # this file will not be overwritten if already exists.
-
+ 
    file "/etc/httpd/conf/httpd.conf",
      source => "/files/etc/httpd/conf/httpd.conf",
      on_change => sub { service httpd => "restart"; };
-
+ 
    file "/etc/named.d",
      ensure => "directory",  # this will create a directory
      owner  => "root",
      group  => "root";
-
+ 
    file "/etc/motd",
      ensure => "absent";   # this will remove the file or directory
-
+ 
  };
 
 If I<source> is relative it will search from the location of your I<Rexfile> or the I<.pm> file if you use Perl packages.
@@ -598,12 +602,12 @@ On failure it will die.
  eval {
    $fh = file_write("/etc/groups");
  };
-
+ 
  # catch an error
  if($@) {
    print "An error occured. $@.\n";
  }
-
+ 
  # work with the filehandle
  $fh->write("...");
  $fh->close;
@@ -655,12 +659,12 @@ On failure it will die.
  eval {
    $fh = read("/etc/groups");
  };
-
+ 
  # catch an error
  if($@) {
    print "An error occured. $@.\n";
  }
-
+ 
  # work with the filehandle
  my $content = $fh->read_all;
  $fh->close;
@@ -840,7 +844,7 @@ Since 0.42 you can use named parameters as well
      on_change => sub {
                 say "file was changed, do something.";
               };
-
+ 
    append_if_no_such_line "/etc/groups",
      line  => "mygroup:*:100:myuser1,myuser2",
      regexp => [qr{^mygroup:}, qr{^ourgroup:}]; # this is an OR
@@ -981,7 +985,7 @@ This function extracts a file. Supported formats are .box, .tar, .tar.gz, .tgz,
     owner => "root",
     group => "root",
     to   => "/etc";
-
+ 
    extract "/tmp/foo.tgz",
     type => "tgz",
     mode => "g+rwX";
@@ -1068,7 +1072,7 @@ Search some string in a file and replace it.
  task sar => sub {
    # this will work line by line
    sed qr{search}, "replace", "/var/log/auth.log";
-
+ 
    # to use it in a multiline way
    sed qr{search}, "replace", "/var/log/auth.log",
     multiline => TRUE;
