@@ -23,7 +23,7 @@ sub new {
 sub start {
   my($self, $service) = @_;
 
-  i_run "/sbin/service $service start >/dev/null";
+  i_run "/sbin/service $service start >/dev/null", nohup => 1;
 
   if($? == 0) {
     return 1;
@@ -35,7 +35,7 @@ sub start {
 sub restart {
   my($self, $service) = @_;
 
-  i_run "/sbin/service $service restart >/dev/null";
+  i_run "/sbin/service $service restart >/dev/null", nohup => 1;
 
   if($? == 0) {
     return 1;
@@ -47,7 +47,7 @@ sub restart {
 sub stop {
   my($self, $service) = @_;
 
-  i_run "/sbin/service $service stop >/dev/null";
+  i_run "/sbin/service $service stop >/dev/null", nohup => 1;
 
   if($? == 0) {
     return 1;
@@ -59,7 +59,7 @@ sub stop {
 sub reload {
   my($self, $service) = @_;
 
-  i_run "/sbin/service $service reload >/dev/null";
+  i_run "/sbin/service $service reload >/dev/null", nohup => 1;
 
   if($? == 0) {
     return 1;
@@ -98,7 +98,7 @@ sub ensure {
 sub action {
   my ($self, $service, $action) = @_;
 
-  i_run "/sbin/service $service $action >/dev/null";
+  i_run "/sbin/service $service $action >/dev/null", nohup => 1;
   if($? == 0) { return 1; }
 }
 
